import pandas as pd
import numpy as np
import time

class ColumnAssignment():
    def __init__(self, target_column, func, source_columns):
        self.name = 'ColumnAssignment'
        self.target_column = target_column
        self.source_columns = source_columns
        self.func = func

    def fit(self, X, y=None, **fit_params):
        start = time.time()
        #
        end = time.time()
        print(f"{self.name} fit successfully in {end-start:.2f} s")
        return self

    def transform(self, X, **transform_params):
        data = X.copy()
        data[self.target_column] = self.func(data, self.source_columns)
        return data

    def execute(self, X):
        self.fit(X)
        return self.transform(X)


import pandas as pd
import numpy as np


# import pkg_resources
# path = 'EzUtils/config.cfg'
# config_path = pkg_resources.resource_filename(__name__, path)


# import configparser

# config_path  = 'config.cfg'
# parser = configparser.ConfigParser()
# parser.read(config_path)
# version = parser['default']['version']

# from ggwp.config.config import EzConfig

# version = EzConfig().__version__

class EzUtils:
    def __init__(self):
        self.__version__ = None
    
    def hello_world(self):
        print("hello world!!")

    def get_q1(self,x):
        return x.quantile(.25)

    def get_q3(self,x):
        return x.quantile(.75)


import pandas as pd
import numpy as np
import time
import functools
import operator

class OneHotTransformer():
    def __init__(self, target_columns):
        self.name = 'OneHotTransformer'
        self.target_columns = target_columns
        self.unique_values = []

    def get_unique(self, X):
        unique_values = []
        for column in self.target_columns:
            unique = list(X[column].unique())
            unique.sort()
            unique_values.append(unique)
        return unique_values

    def get_onehot(self, X):
        for enum, column in enumerate(self.target_columns):
            unique_values = self.unique_values[enum]
            for unique_value in unique_values:
                X[f"{column}_{unique_value}"] = np.where(X[column]==unique_value, 1, 0)
        return X.drop(self.target_columns, axis=1)

    def fit(self, X, y=None, **fit_params):
        start = time.time()
        self.unique_values = self.get_unique(X)
        end = time.time()
        print(f"{self.name} fit successfully in {end-start:.2f} s")
        return self

    def transform(self, X, **transform_params):
        data = X.copy()
        unique_values = self.get_unique(X)
        if unique_values !=  self.unique_values:
            raise ValueError("New values did not match. Please re-check your data again")
        else:
            return self.get_onehot(data)


    def execute(self, X):
        self.fit(X)
        return self.transform(X)